summaryrefslogtreecommitdiffstats
path: root/vm/ReferenceTable.h
diff options
context:
space:
mode:
authorJean-Baptiste Queru <jbq@google.com>2009-11-12 18:45:15 -0800
committerJean-Baptiste Queru <jbq@google.com>2009-11-12 18:45:15 -0800
commit72e93344b4d1ffc71e9c832ec23de0657e5b04a5 (patch)
tree1a08d1e43d54200ea737234d865c4668c5d3535b /vm/ReferenceTable.h
parentdfd0afbcb08b871e224a28ecb4ed427a7693545c (diff)
downloadandroid_dalvik-72e93344b4d1ffc71e9c832ec23de0657e5b04a5.tar.gz
android_dalvik-72e93344b4d1ffc71e9c832ec23de0657e5b04a5.tar.bz2
android_dalvik-72e93344b4d1ffc71e9c832ec23de0657e5b04a5.zip
eclair snapshot
Diffstat (limited to 'vm/ReferenceTable.h')
-rw-r--r--vm/ReferenceTable.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/vm/ReferenceTable.h b/vm/ReferenceTable.h
index f8f24610e..d6e2d705a 100644
--- a/vm/ReferenceTable.h
+++ b/vm/ReferenceTable.h
@@ -13,6 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
+
/*
* Maintain a table of references. Used for internal local references,
* JNI locals, JNI globals, and GC heap references.
@@ -36,8 +37,8 @@
* table/nextEntry is allowed.)
*/
typedef struct ReferenceTable {
- Object** table; /* top of the list */
- Object** nextEntry; /* bottom of the list */
+ Object** nextEntry; /* top of the list */
+ Object** table; /* bottom of the list */
int allocEntries; /* #of entries we have space for */
int maxEntries; /* max #of entries allowed */
@@ -88,23 +89,24 @@ INLINE size_t dvmIsReferenceTableFull(const ReferenceTable* pRef)
bool dvmAddToReferenceTable(ReferenceTable* pRef, Object* obj);
/*
* Determine if "obj" is present in "pRef". Stops searching when we hit "top".
* To include the entire table, pass in "pRef->table" as the top.
*
* Returns NULL if "obj" was not found.
*/
-Object** dvmFindInReferenceTable(const ReferenceTable* pRef, Object** top,
+Object** dvmFindInReferenceTable(const ReferenceTable* pRef, Object** bottom,
Object* obj);
/*
* Remove an existing entry.
*
* We stop searching for a match after examining the element at "top". This
* is useful when entries are associated with a stack frame.
*
* Returns "false" if the entry was not found.
*/
-bool dvmRemoveFromReferenceTable(ReferenceTable* pRef, Object** top,
+bool dvmRemoveFromReferenceTable(ReferenceTable* pRef, Object** bottom,
Object* obj);
/*
@@ -88,23 +89,24 @@ INLINE size_t dvmIsReferenceTableFull(const ReferenceTable* pRef)
bool dvmAddToReferenceTable(ReferenceTable* pRef, Object* obj);
/*
- * Determine if "obj" is present in "pRef". Stops searching when we hit "top".
- * To include the entire table, pass in "pRef->table" as the top.
+ * Determine if "obj" is present in "pRef". Stops searching when we hit
+ * "bottom". To include the entire table, pass in "pRef->table" as the
+ * bottom.
*
* Returns NULL if "obj" was not found.
@@ -88,23 +89,24 @@ INLINE size_t dvmIsReferenceTableFull(const ReferenceTable* pRef)
* Remove an existing entry.
*
- * We stop searching for a match after examining the element at "top". This
- * is useful when entries are associated with a stack frame.
+ * We stop searching for a match after examining the element at "bottom".
+ * This is useful when entries are associated with a stack frame.
*
* Returns "false" if the entry was not found.